import DarkModeOutlined from '@mui/icons-material/DarkModeOutlined'
import LightModeOutlined from '@mui/icons-material/LightModeOutlined'
import AppBar from '@mui/material/AppBar'
import Avatar from '@mui/material/Avatar'
import IconButton from '@mui/material/IconButton'
import Stack from '@mui/material/Stack'
import Toolbar from '@mui/material/Toolbar'
import Typography from '@mui/material/Typography'
import {useGetIdentity, usePermissions} from '@refinedev/core'
import {HamburgerMenu, RefineThemedLayoutV2HeaderProps} from '@refinedev/mui'
import React, {useContext} from 'react'
import {ColorModeContext} from '../../contexts/color-mode'

type IUser = {
  id: number
  name: string
  avatar: string
  is_admin: boolean
}

export const Header: React.FC<RefineThemedLayoutV2HeaderProps> = ({sticky = true}) => {
  const {mode, setMode} = useContext(ColorModeContext)
  const {data: user} = useGetIdentity<IUser>()
  const {data: permissions} = usePermissions<string[]>()
  const isAdmin = permissions?.includes('admin')

  return (
    <AppBar position={sticky ? 'sticky' : 'relative'}>
      <Toolbar>
        <Stack direction="row" width="100%" justifyContent="flex-end" alignItems="center">
          <HamburgerMenu />
          <Stack direction="row" width="100%" justifyContent="flex-end" alignItems="center">
            <IconButton
              color="inherit"
              onClick={() => {
                setMode()
              }}
              sx={{
                marginRight: '2px',
              }}
            >
              {mode === 'dark' ? <LightModeOutlined /> : <DarkModeOutlined />}
            </IconButton>

            {(user?.avatar || user?.name) && (
              <Stack direction="row" gap="16px" alignItems="center" justifyContent="center">
                {user?.name && (
                  <Stack direction="column" alignItems="start" gap="0px">
                    <Typography
                      sx={{
                        display: {
                          xs: 'none',
                          sm: 'inline-block',
                        },
                      }}
                      variant="subtitle2"
                    >
                      {user?.name}
                    </Typography>

                    <Typography
                      sx={{
                        display: {
                          xs: 'none',
                          sm: 'inline-block',
                        },
                        backgroundColor: 'primary.main',
                        color: 'text.secondary',
                        padding: '1px 4px',
                        borderRadius: 1,
                        fontSize: '0.6rem',
                      }}
                      variant="subtitle2"
                    >
                      {isAdmin ? 'Администратор' : 'Пользователь'}
                    </Typography>
                  </Stack>
                )}
                <Avatar src={user?.avatar} alt={user?.name} />
              </Stack>
            )}
          </Stack>
        </Stack>
      </Toolbar>
    </AppBar>
  )
}
